//	Copyright  2000.	GSI Technology
//	apps@gsitechnology.com
//  v 1.00  06/21/06    Jeff Daugherty  1) Created 
//
//

`timescale 1ps / 1ps

module G81302T08E#(
		    parameter SPEED = 300,
                              A_bits = 1
)
  (A8130, DQ,  nNW, K, nK, C, nC, nLD, RnW, nDoff, ZQ, CQ, nCQ, TMS, TDI, TDO, TCK );
   input [22:0] 	      A8130; 		// address
   input 		      K;		// clock
   input 		      nK;		// clock
   input 		      C;		// clock
   input 		      nC ;		// clock
   input [1:0] 		      nNW;		// bank 1 write enable
   input 		      nLD; 		// read enable
   input 		      RnW; 		// write enable
   input 		      nDoff; 		// write enable
   input 		      ZQ; 		// write enable
   output 		      CQ; 		// write enable
   output 		      nCQ; 		// write enable
   inout [7:0] 		      DQ;		// data in
   input 		      TMS;		// Scan Test Mode Select
   input 		      TDI;		// Scan Test Data In
   output 		      TDO;		// Scan Test Data Out
   input 		      TCK;		// Scan Test Clock

//---------------------------------------------------------------
// 	Scan Registers 
//---------------------------------------------------------------
   wire [3:0]	tBW;
   wire [23:0] 	A;
   assign 	A = {A8130,1'b0};
   assign 	tBW = {1'b1, 1'b1, nNW};
   	
   parameter 	tCHQV     =  450;
   parameter 	tCHQX     = -450;
   parameter 	tCHQV_off =  2000;
   parameter 	tCHQX_off =  0;
   parameter    mem_size  =  A_bits > 1 ? A_bits : 24;
   parameter    mem_style =  A_bits > 1 ? "REDUCED" : "NORMAL";

   initial begin
      if (SPEED==333 | SPEED==300 | SPEED==250 | SPEED==200 | SPEED==167) begin
	 //do nothing
      end // if (SPEED == 333 | SPEED==300 | SPEED==250 | SPEED==200 | SPEED==167)
      else begin
	 $display ("INVALID SPEED option, allowable SPEEDs options are 333, 300, 250, 200, 167. SPEED = %d", SPEED);
	 $stop;
      end // else: !if(SPEED == 333 | SPEED==300 | SPEED==250 | SPEED==200 | SPEED==167)
   end

   core_cio_b2 #( .A_size(24),
		  .A_bits(A_bits),
		  .DQ_width(8),
		  .ECC(0),
		  .HighZ(8'bZZZZZZZZ),
		  .bank_size(2**mem_size),
		  .mem_style(mem_style),
		  .mem_size(mem_size),
		  .tCHQV(tCHQV),
    		  .tCHQX(tCHQX),
    		  .tCQHQV((SPEED==333) ?  250 : (SPEED==300) ?  270 : (SPEED==250) ?  300 : (SPEED==200) ?  350 :  400),
    		  .tCQHQX((SPEED==333) ? -250 : (SPEED==300) ? -270 : (SPEED==250) ? -300 : (SPEED==200) ? -350 : -400),
    		  .tCHQV_off(tCHQV_off),
    		  .tCHQX_off(tCHQX_off))
     core_cio_b2(.A     (A),
		 .DQ    (DQ),
		 .tBW   (tBW),
		 .K     (K),
		 .nK    (nK),
		 .C     (C),
		 .nC    (nC),
		 .nLD   (nLD),
		 .RnW   (RnW),
		 .nDoff (nDoff),
		 .CQ    (CQ),
		 .nCQ   (nCQ),
		 .TCK   (TCK));

endmodule
